aboutsummaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorThe Android Open Source Project <initial-contribution@android.com>2009-03-18 17:39:44 -0700
committerThe Android Open Source Project <initial-contribution@android.com>2009-03-18 17:39:44 -0700
commit8053228ee51a6de1923de95fdf6a8f02521a65d9 (patch)
tree361886acf24b916260a55875c5b59951d6e9e105
parent2c918c82a1735eeaba8cf84d1985b1b1c2ba0018 (diff)
downloadopencore-8053228ee51a6de1923de95fdf6a8f02521a65d9.tar.gz
auto import from //branches/cupcake_rel/...@140373
-rw-r--r--Android.mk2
-rw-r--r--Config.mk19
-rw-r--r--android/author/authordriver.cpp41
-rw-r--r--android/author/authordriver.h6
-rw-r--r--codecs_v2/omx/factories/omx_m4v_factory/src/omx_m4v_component_interface.cpp37
-rwxr-xr-xcodecs_v2/omx/omx_common/src/pv_omxregistry.cpp4
-rw-r--r--engines/player/Android.mk21
-rw-r--r--engines/player/config/linux_nj/pv_player_node_registry.cpp20
-rw-r--r--oscl/oscl/oscllib/Android.mk3
-rw-r--r--pvcommon/Android.mk11
-rw-r--r--pvplayer/Android.mk28
-rw-r--r--tools_v2/build/modules/linux_download/core/Android.mk2
-rw-r--r--tools_v2/build/modules/linux_download/node_registry/Android.mk2
-rw-r--r--tools_v2/build/modules/linux_mp4/core/Android.mk2
-rw-r--r--tools_v2/build/modules/linux_mp4/node_registry/Android.mk2
-rw-r--r--tools_v2/build/modules/linux_net_support/core/Android.mk2
-rw-r--r--tools_v2/build/modules/linux_rtsp/core/Android.mk2
-rw-r--r--tools_v2/build/modules/linux_rtsp/node_registry/Android.mk2
18 files changed, 157 insertions, 49 deletions
diff --git a/Android.mk b/Android.mk
index ee47dd1c3..00cc3fdf5 100644
--- a/Android.mk
+++ b/Android.mk
@@ -8,7 +8,7 @@ include $(LOCAL_PATH)/Config.mk
# Install the default configuration file
# if no value-add configuration is present.
-ifneq ($(VALUE_ADD),1)
+ifeq ($(VALUE_ADD), false)
$(call add-prebuilt-files, ETC, pvplayer.conf)
endif
diff --git a/Config.mk b/Config.mk
index 163e56455..957ae4092 100644
--- a/Config.mk
+++ b/Config.mk
@@ -8,24 +8,25 @@ ifndef EXTERNAL_OPENCORE_CONFIG_ONCE
# HAS_OSCL_LIB_SUPPORT turns on PV's OSCL dynamic loader.
# Set PV_OSCL_LIB to true to enable it (default in release mode).
+ # To enable the value added modules, HAS_OSCL_LIB_SUPPORT must be true.
+ #
# However for debugging with gdb you may want to set PV_OSCL_LIB to
# false to disable this custom loader.
PV_OSCL_LIB := true
+ VALUE_ADD := false
ifeq ($(PV_OSCL_LIB), true)
PV_CFLAGS += -DHAS_OSCL_LIB_SUPPORT
- endif
-
- PV_COPY_HEADERS_TO := libpv
- alternate_config := $(if $(wildcard vendor/pv/pvplayer.conf),true)
- ifeq ($(alternate_config), true)
- VALUE_ADD := 1
- PV_CFLAGS += -DPV_USE_VALUE_ADD=1
- else
- VALUE_ADD :=
+ alternate_config := $(if $(wildcard vendor/pv/pvplayer.conf),true)
+ ifeq ($(alternate_config), true)
+ VALUE_ADD := true
+ PV_CFLAGS += -DPV_USE_VALUE_ADD=1
+ endif
endif
alternate_config :=
+ PV_COPY_HEADERS_TO := libpv
+
PV_INCLUDES := \
$(PV_TOP)/android \
$(PV_TOP)/extern_libs_v2/khronos/openmax/include \
diff --git a/android/author/authordriver.h b/android/author/authordriver.h
index aeada4111..dcd9295b6 100644
--- a/android/author/authordriver.h
+++ b/android/author/authordriver.h
@@ -269,7 +269,11 @@ private:
// Callback for synchronous commands.
static void syncCompletion(status_t s, void *cookie);
- PVMFStatus setMaxDuration(int64_t max_duration_ms);
+ // Limit either the duration of the recording or the resulting file size
+ // If "limit_is_duration" is true, "limit" holds the maximum duration in
+ // milliseconds, otherwise "limit" holds the maximum filesize in bytes.
+ PVMFStatus setMaxDurationOrFileSize(int64_t limit, bool limit_is_duration);
+
PVMFStatus setParameter(const String8 &key, const String8 &value);
PVAuthorEngineInterface *mAuthor;
diff --git a/codecs_v2/omx/omx_common/src/pv_omxregistry.cpp b/codecs_v2/omx/omx_common/src/pv_omxregistry.cpp
index d13304c8d..7b2c96f41 100755
--- a/codecs_v2/omx/omx_common/src/pv_omxregistry.cpp
+++ b/codecs_v2/omx/omx_common/src/pv_omxregistry.cpp
@@ -51,6 +51,9 @@ OMX_ERRORTYPE AvcRegister(ComponentRegistrationType **);
#endif
#if REGISTER_OMX_WMV_COMPONENT
+#ifndef PV_USE_VALUE_ADD
+#error "Try to use the WMV component but PV_USE_VALUE_ADD is undef"
+#endif
#include "omx_wmv_component_interface.h"
OMX_ERRORTYPE WmvRegister(ComponentRegistrationType **);
#endif
@@ -440,4 +443,3 @@ OMX_ERRORTYPE Mp3Register(ComponentRegistrationType **aTemplateList)
return OMX_ErrorNone;
}
#endif
-
diff --git a/engines/player/Android.mk b/engines/player/Android.mk
index 4f9a45034..108642b76 100644
--- a/engines/player/Android.mk
+++ b/engines/player/Android.mk
@@ -4,20 +4,13 @@ include $(CLEAR_VARS)
LOCAL_SRC_FILES := \
src/pv_player_datapath.cpp \
src/pv_player_engine.cpp \
- src/pv_player_factory.cpp
-
-
-ifeq ($(FORMAT),nj)
- LOCAL_SRC_FILES += src/../config/linux_nj/pv_player_node_registry.cpp
-else
- LOCAL_SRC_FILES += src/../config/linux_nj/pv_player_node_registry.cpp
-endif
+ src/pv_player_factory.cpp \
+ config/linux_nj/pv_player_node_registry.cpp
LOCAL_MODULE := libpvplayer_engine
LOCAL_CFLAGS := $(PV_CFLAGS)
-
LOCAL_C_INCLUDES := \
$(PV_TOP)//engines/player/include \
$(PV_TOP)//engines/player/src \
@@ -42,13 +35,19 @@ LOCAL_C_INCLUDES := \
$(PV_TOP)/pvmi/recognizer/plugins/pvmp3ffrecognizer/include \
$(PV_INCLUDES)
+
+ifeq ($(PV_OSCL_LIB), false)
+ LOCAL_C_INCLUDES += $(PV_TOP)/nodes/streaming/streamingmanager/include
+endif
+
+
ifeq ($(ARCHITECTURE),linux_nj)
LOCAL_C_INCLUDES += $(PV_TOP)//engines/player/config/linux_nj
else
ifeq ($(FORMAT),nj)
- LOCAL_C_INCLUDES += $(PV_TOP)//engines/player/config/linux_nj
+ LOCAL_C_INCLUDES += $(PV_TOP)//engines/player/config/linux_nj
else
- LOCAL_C_INCLUDES += $(PV_TOP)//engines/player/config/linux_nj
+ LOCAL_C_INCLUDES += $(PV_TOP)//engines/player/config/linux_nj
endif
endif
diff --git a/engines/player/config/linux_nj/pv_player_node_registry.cpp b/engines/player/config/linux_nj/pv_player_node_registry.cpp
index 787f731a6..c0d801dfa 100644
--- a/engines/player/config/linux_nj/pv_player_node_registry.cpp
+++ b/engines/player/config/linux_nj/pv_player_node_registry.cpp
@@ -46,6 +46,11 @@
#include "oscl_shared_library.h"
#include "pvmf_node_shared_lib_interface.h"
+
+#else
+
+#include "pvmf_sm_node_factory.h"
+
#endif
PVPlayerNodeRegistry::PVPlayerNodeRegistry()
@@ -131,6 +136,19 @@ PVPlayerNodeRegistry::PVPlayerNodeRegistry()
nodeinfo.iNodeCreateFunc = PVMFWAVFFParserNodeFactory::CreatePVMFWAVFFParserNode;
nodeinfo.iNodeReleaseFunc = PVMFWAVFFParserNodeFactory::DeletePVMFWAVFFParserNode;
iType.push_back(nodeinfo);
+
+#ifndef HAS_OSCL_LIB_SUPPORT
+ // For PVMFStreamingManagerNode
+ nodeinfo.iInputTypes.clear();
+ nodeinfo.iInputTypes.push_back(PVMF_DATA_SOURCE_RTSP_URL);
+ nodeinfo.iInputTypes.push_back(PVMF_DATA_SOURCE_SDP_FILE);
+ nodeinfo.iNodeUUID = KPVMFStreamingManagerNodeUuid;
+ nodeinfo.iOutputType.clear();
+ nodeinfo.iOutputType.push_back(PVMF_FORMAT_UNKNOWN);
+ nodeinfo.iNodeCreateFunc = PVMFStreamingManagerNodeFactory::CreateStreamingManagerNode;
+ nodeinfo.iNodeReleaseFunc = PVMFStreamingManagerNodeFactory::DeleteStreamingManagerNode;
+ iType.push_back(nodeinfo);
+#endif // !HAS_OSCL_LIB_SUPPORT
}
@@ -526,5 +544,3 @@ void PVPlayerRecognizerRegistry::RecognizerCommandCompleted(const PVMFCmdResp& a
RunIfNotReady();
}
-
-
diff --git a/oscl/oscl/oscllib/Android.mk b/oscl/oscl/oscllib/Android.mk
index c645a81b9..1a155468a 100644
--- a/oscl/oscl/oscllib/Android.mk
+++ b/oscl/oscl/oscllib/Android.mk
@@ -1,3 +1,4 @@
+ifeq ($(PV_OSCL_LIB), true)
LOCAL_PATH := $(call my-dir)
include $(CLEAR_VARS)
@@ -27,4 +28,4 @@ LOCAL_COPY_HEADERS := \
src/oscl_library_list.h
include $(BUILD_STATIC_LIBRARY)
-
+endif # PV_OSCL_LIB \ No newline at end of file
diff --git a/pvcommon/Android.mk b/pvcommon/Android.mk
index 4ce03deba..a8238e030 100644
--- a/pvcommon/Android.mk
+++ b/pvcommon/Android.mk
@@ -13,7 +13,6 @@ LOCAL_WHOLE_STATIC_LIBRARIES := \
libosclio \
libosclregcli \
libosclregserv \
- liboscllib \
libpvmf \
libpvmimeutils \
libpvfileoutputnode \
@@ -23,6 +22,10 @@ LOCAL_WHOLE_STATIC_LIBRARIES := \
libpv_amr_nb_common_lib \
libpv_avc_common_lib
+ifeq ($(PV_OSCL_LIB), true)
+ LOCAL_WHOLE_STATIC_LIBRARIES += liboscllib
+endif
+
LOCAL_LDLIBS := -lpthread
LOCAL_SHARED_LIBRARIES := libutils libcutils libhardware libandroid_runtime
@@ -52,7 +55,6 @@ include $(PV_TOP)//oscl/oscl/osclio/Android.mk
include $(PV_TOP)//oscl/oscl/osclregcli/Android.mk
include $(PV_TOP)//oscl/oscl/osclregserv/Android.mk
include $(PV_TOP)//oscl/unit_test/Android.mk
-include $(PV_TOP)//oscl/oscl/oscllib/Android.mk
include $(PV_TOP)//pvmi/pvmf/Android.mk
include $(PV_TOP)//baselibs/pv_mime_utils/Android.mk
include $(PV_TOP)//nodes/pvfileoutputnode/Android.mk
@@ -61,4 +63,9 @@ include $(PV_TOP)//baselibs/threadsafe_callback_ao/Android.mk
include $(PV_TOP)//codecs_v2/utilities/colorconvert/Android.mk
include $(PV_TOP)//codecs_v2/audio/gsm_amr/amr_nb/common/Android.mk
include $(PV_TOP)//codecs_v2/video/avc_h264/common/Android.mk
+
+ifeq ($(PV_OSCL_LIB), true)
+ include $(PV_TOP)//oscl/oscl/oscllib/Android.mk
+endif
+
endif
diff --git a/pvplayer/Android.mk b/pvplayer/Android.mk
index ffa916605..e74c98032 100644
--- a/pvplayer/Android.mk
+++ b/pvplayer/Android.mk
@@ -47,12 +47,32 @@ LOCAL_WHOLE_STATIC_LIBRARIES := \
libandroidpv \
libkmj_oma1
-LOCAL_LDLIBS := -lpthread
-
-ifeq ($(VALUE_ADD),1)
-LOCAL_WHOLE_STATIC_LIBRARIES += libomx_wmv_component_interface
+ifeq ($(PV_OSCL_LIB), true)
+ ifeq ($(VALUE_ADD), true)
+ LOCAL_WHOLE_STATIC_LIBRARIES += libomx_wmv_component_interface
+ endif
+else
+ # Since OSCL dynamic lib is disabled, we need to statically link
+ # the required libraries.
+ LOCAL_WHOLE_STATIC_LIBRARIES += \
+ libomx_m4v_component_lib \
+ libpvmp4decoder \
+ libprotocolenginenode \
+ libpv_http_parcom \
+ libpv_rtsp_parcom \
+ libpvgendatastruct \
+ libpvjitterbuffernode \
+ libpvmediaplayernode \
+ libpvrtsp_cli_eng_node_3gpp \
+ libpvsdpparser \
+ libpvsocketnode \
+ libpvstreamingmanagernode_3gpp \
+ librtppayloadparser_3gpp \
+ librtprtcp
endif
+LOCAL_LDLIBS := -lpthread
+
LOCAL_SHARED_LIBRARIES := libutils libcutils libui libhardware libandroid_runtime libdrm1 libmedia libsgl libvorbisidec libsonivox libopencorecommon libicuuc
ifeq ($(TARGET_OS)-$(TARGET_SIMULATOR),linux-true)
LOCAL_LDLIBS += -ldl
diff --git a/tools_v2/build/modules/linux_download/core/Android.mk b/tools_v2/build/modules/linux_download/core/Android.mk
index 51b1fceb0..028cc9f1c 100644
--- a/tools_v2/build/modules/linux_download/core/Android.mk
+++ b/tools_v2/build/modules/linux_download/core/Android.mk
@@ -1,3 +1,4 @@
+ifeq ($(PV_OSCL_LIB), true)
LOCAL_PATH := $(call my-dir)
include $(CLEAR_VARS)
@@ -16,3 +17,4 @@ LOCAL_C_INCLUDES := \
$(PV_INCLUDES)
include $(BUILD_SHARED_LIBRARY)
+endif # PV_OSCL_LIB \ No newline at end of file
diff --git a/tools_v2/build/modules/linux_download/node_registry/Android.mk b/tools_v2/build/modules/linux_download/node_registry/Android.mk
index 8961eb2bc..60d9f1168 100644
--- a/tools_v2/build/modules/linux_download/node_registry/Android.mk
+++ b/tools_v2/build/modules/linux_download/node_registry/Android.mk
@@ -1,3 +1,4 @@
+ifeq ($(PV_OSCL_LIB), true)
LOCAL_PATH := $(call my-dir)
include $(CLEAR_VARS)
@@ -16,3 +17,4 @@ LOCAL_C_INCLUDES := \
$(PV_INCLUDES)
include $(BUILD_SHARED_LIBRARY)
+endif # PV_OSCL_LIB
diff --git a/tools_v2/build/modules/linux_mp4/core/Android.mk b/tools_v2/build/modules/linux_mp4/core/Android.mk
index e2e192950..7c658061d 100644
--- a/tools_v2/build/modules/linux_mp4/core/Android.mk
+++ b/tools_v2/build/modules/linux_mp4/core/Android.mk
@@ -1,3 +1,4 @@
+ifeq ($(PV_OSCL_LIB), true)
LOCAL_PATH := $(call my-dir)
include $(CLEAR_VARS)
@@ -21,4 +22,5 @@ LOCAL_C_INCLUDES := \
LOCAL_CFLAGS := $(PV_CFLAGS)
include $(BUILD_SHARED_LIBRARY)
+endif # PV_OSCL_LIB
diff --git a/tools_v2/build/modules/linux_mp4/node_registry/Android.mk b/tools_v2/build/modules/linux_mp4/node_registry/Android.mk
index 27fd01996..98b4df610 100644
--- a/tools_v2/build/modules/linux_mp4/node_registry/Android.mk
+++ b/tools_v2/build/modules/linux_mp4/node_registry/Android.mk
@@ -1,3 +1,4 @@
+ifeq ($(PV_OSCL_LIB), true)
LOCAL_PATH := $(call my-dir)
include $(CLEAR_VARS)
@@ -18,4 +19,5 @@ LOCAL_C_INCLUDES := \
LOCAL_CFLAGS := $(PV_CFLAGS)
include $(BUILD_SHARED_LIBRARY)
+endif # PV_OSCL_LIB
diff --git a/tools_v2/build/modules/linux_net_support/core/Android.mk b/tools_v2/build/modules/linux_net_support/core/Android.mk
index 5e6ac4808..17952fbac 100644
--- a/tools_v2/build/modules/linux_net_support/core/Android.mk
+++ b/tools_v2/build/modules/linux_net_support/core/Android.mk
@@ -1,3 +1,4 @@
+ifeq ($(PV_OSCL_LIB), true)
LOCAL_PATH := $(call my-dir)
include $(CLEAR_VARS)
@@ -19,4 +20,5 @@ LOCAL_C_INCLUDES := \
LOCAL_CFLAGS := $(PV_CFLAGS)
include $(BUILD_SHARED_LIBRARY)
+endif # PV_OSCL_LIB
diff --git a/tools_v2/build/modules/linux_rtsp/core/Android.mk b/tools_v2/build/modules/linux_rtsp/core/Android.mk
index 14d1786eb..7bd3d24a8 100644
--- a/tools_v2/build/modules/linux_rtsp/core/Android.mk
+++ b/tools_v2/build/modules/linux_rtsp/core/Android.mk
@@ -1,3 +1,4 @@
+ifeq ($(PV_OSCL_LIB), true)
LOCAL_PATH := $(call my-dir)
include $(CLEAR_VARS)
@@ -23,3 +24,4 @@ LOCAL_C_INCLUDES := \
LOCAL_CFLAGS := $(PV_CFLAGS)
include $(BUILD_SHARED_LIBRARY)
+endif # PV_OSCL_LIB \ No newline at end of file
diff --git a/tools_v2/build/modules/linux_rtsp/node_registry/Android.mk b/tools_v2/build/modules/linux_rtsp/node_registry/Android.mk
index dd382fdbf..ac8dfc737 100644
--- a/tools_v2/build/modules/linux_rtsp/node_registry/Android.mk
+++ b/tools_v2/build/modules/linux_rtsp/node_registry/Android.mk
@@ -1,3 +1,4 @@
+ifeq ($(PV_OSCL_LIB), true)
LOCAL_PATH := $(call my-dir)
include $(CLEAR_VARS)
@@ -16,4 +17,5 @@ LOCAL_C_INCLUDES := \
LOCAL_CFLAGS := $(PV_CFLAGS)
include $(BUILD_SHARED_LIBRARY)
+endif # PV_OSCL_LIB
diff --git a/android/author/authordriver.cpp b/android/author/authordriver.cpp
index 37d3c7ef1..d642e0034 100644
--- a/android/author/authordriver.cpp
+++ b/android/author/authordriver.cpp
@@ -148,14 +148,11 @@ author_command *AuthorDriver::dequeueCommand()
status_t AuthorDriver::enqueueCommand(author_command *ac, media_completion_f comp, void *cookie)
{
- int sync_wait = 0;
-
// If the user didn't specify a completion callback, we
// are running in synchronous mode.
if (comp == NULL) {
ac->comp = AuthorDriver::syncCompletion;
ac->cookie = this;
- sync_wait = 1;
} else {
ac->comp = comp;
ac->cookie = cookie;
@@ -558,11 +555,12 @@ exit:
}
}
-PVMFStatus AuthorDriver::setMaxDuration(int64_t max_duration_ms) {
+PVMFStatus AuthorDriver::setMaxDurationOrFileSize(
+ int64_t limit, bool limit_is_duration) {
PVInterface *interface;
PvmfComposerSizeAndDurationInterface *durationConfig;
- if (max_duration_ms > 0xffffffff) {
+ if (limit > 0xffffffff) {
// PV API expects this to fit in a uint32.
return PVMFErrArgument;
}
@@ -581,11 +579,20 @@ PVMFStatus AuthorDriver::setMaxDuration(int64_t max_duration_ms) {
return PVMFFailure;
}
- // SetMaxDuration's first parameter is a boolean "enable", we enable
- // enforcement of the maximum duration if it's (strictly) positive,
- // otherwise we take it to imply disabling.
- PVMFStatus ret = durationConfig->SetMaxDuration(
- max_duration_ms > 0, static_cast<uint32>(max_duration_ms));
+ PVMFStatus ret;
+ if (limit_is_duration) {
+ // SetMaxDuration's first parameter is a boolean "enable", we enable
+ // enforcement of the maximum duration if it's (strictly) positive,
+ // otherwise we take it to imply disabling.
+ ret = durationConfig->SetMaxDuration(
+ limit > 0, static_cast<uint32>(limit));
+ } else {
+ // SetMaxFileSize's first parameter is a boolean "enable", we enable
+ // enforcement of the maximum filesize if it's (strictly) positive,
+ // otherwise we take it to imply disabling.
+ ret = durationConfig->SetMaxFileSize(
+ limit > 0, static_cast<uint32>(limit));
+ }
durationConfig->removeRef();
durationConfig = NULL;
@@ -637,7 +644,14 @@ PVMFStatus AuthorDriver::setParameter(
if (key == "max-duration") {
int64_t max_duration_ms;
if (safe_strtoi64(value.string(), &max_duration_ms)) {
- return setMaxDuration(max_duration_ms);
+ return setMaxDurationOrFileSize(
+ max_duration_ms, true /* limit_is_duration */);
+ }
+ } else if (key == "max-filesize") {
+ int64_t max_filesize_bytes;
+ if (safe_strtoi64(value.string(), &max_filesize_bytes)) {
+ return setMaxDurationOrFileSize(
+ max_filesize_bytes, false /* limit is filesize */);
}
}
@@ -680,7 +694,7 @@ void AuthorDriver::handleSetParameters(set_parameters_command *ac) {
ret = setParameter(key, value);
- if (ret != NO_ERROR) {
+ if (ret != PVMFSuccess) {
LOGE("setParameter(%s = %s) failed with result %d",
key.string(), value.string(), ret);
break;
@@ -989,6 +1003,9 @@ static int GetMediaRecorderInfoCode(const PVAsyncInformationalEvent& aEvent) {
case PVMF_COMPOSER_MAXDURATION_REACHED:
return MEDIA_RECORDER_INFO_MAX_DURATION_REACHED;
+ case PVMF_COMPOSER_MAXFILESIZE_REACHED:
+ return MEDIA_RECORDER_INFO_MAX_FILESIZE_REACHED;
+
default:
return MEDIA_RECORDER_INFO_UNKNOWN;
}
diff --git a/codecs_v2/omx/factories/omx_m4v_factory/src/omx_m4v_component_interface.cpp b/codecs_v2/omx/factories/omx_m4v_factory/src/omx_m4v_component_interface.cpp
index 4730fb0c2..e0e0f6722 100644
--- a/codecs_v2/omx/factories/omx_m4v_factory/src/omx_m4v_component_interface.cpp
+++ b/codecs_v2/omx/factories/omx_m4v_factory/src/omx_m4v_component_interface.cpp
@@ -20,6 +20,7 @@
#include "pv_omxdefs.h"
#include "omx_mpeg4_component.h"
+#ifdef HAS_OSCL_LIB_SUPPORT
#include "oscl_shared_library.h"
#include "pvmf_node_shared_lib_interface.h"
@@ -34,10 +35,22 @@
OsclSharedLibrary* OmxM4vComponentFactory::iOmxLib = NULL;
int OmxM4vComponentFactory::iRefCount = 0;
+#else
+// External factory functions needed for the creation of each component. Defined
+// in codec_v2/omx/omx_m4v/src/omx_mpeg4_component.cpp.
+extern OMX_ERRORTYPE Mpeg4OmxComponentFactory(OMX_OUT OMX_HANDLETYPE* pHandle, OMX_IN OMX_PTR pAppData);
+extern OMX_ERRORTYPE Mpeg4OmxComponentDestructor(OMX_IN OMX_HANDLETYPE pHandle);
+
+extern OMX_ERRORTYPE H263OmxComponentFactory(OMX_OUT OMX_HANDLETYPE* pHandle, OMX_IN OMX_PTR pAppData);
+extern OMX_ERRORTYPE H263OmxComponentDestructor(OMX_IN OMX_HANDLETYPE pHandle);
+
+#endif // HAS_OSCL_LIB_SUPPORT
+
// This function is called by OMX_GetHandle and it creates an instance of the m4v component AO
// by loading the library where libomx_m4v_component_lib is located
OMX_ERRORTYPE OmxM4vComponentFactory::M4vCreate(OMX_OUT OMX_HANDLETYPE* pHandle, OMX_IN OMX_PTR pAppData)
{
+#ifdef HAS_OSCL_LIB_SUPPORT
OSCL_StackString<M4V_MAX_LIB_PATH> omxLibName(OMX_M4V_LIB_NAME);
OsclSharedLibrary* lib = NULL;
@@ -95,12 +108,15 @@ OMX_ERRORTYPE OmxM4vComponentFactory::M4vCreate(OMX_OUT OMX_HANDLETYPE* pHandle,
OmxM4vComponentFactory::iOmxLib = NULL;
}
}
-
return OMX_ErrorUndefined;
+#else
+ return Mpeg4OmxComponentFactory(pHandle, pAppData);
+#endif
}
OMX_ERRORTYPE OmxM4vComponentFactory::M4vDestructor(OMX_IN OMX_HANDLETYPE pHandle)
{
+#ifdef HAS_OSCL_LIB_SUPPORT
OsclSharedLibrary* lib = OmxM4vComponentFactory::iOmxLib;
// lib must not be NULL at this point. If the omx component has been
@@ -140,12 +156,16 @@ OMX_ERRORTYPE OmxM4vComponentFactory::M4vDestructor(OMX_IN OMX_HANDLETYPE pHandl
}
return returnStatus;
+#else
+ return Mpeg4OmxComponentDestructor(pHandle);
+#endif
}
// This function is called by OMX_GetHandle and it creates an instance of the m4v component AO
// by loading the library where libomx_m4v_component_lib is located
OMX_ERRORTYPE OmxM4vComponentFactory::H263Create(OMX_OUT OMX_HANDLETYPE* pHandle, OMX_IN OMX_PTR pAppData)
{
+#ifdef HAS_OSCL_LIB_SUPPORT
OSCL_StackString<M4V_MAX_LIB_PATH> omxLibName(OMX_M4V_LIB_NAME);
OsclSharedLibrary* lib = NULL;
@@ -165,7 +185,7 @@ OMX_ERRORTYPE OmxM4vComponentFactory::H263Create(OMX_OUT OMX_HANDLETYPE* pHandle
OmxM4vComponentFactory::iRefCount++;
// Load the associated library. If successful, call the corresponding
// create function for OMX M4V.
if (OsclLibSuccess == lib->LoadLib())
{
OsclAny* interfacePtr = NULL;
@@ -205,10 +225,15 @@ OMX_ERRORTYPE OmxM4vComponentFactory::H263Create(OMX_OUT OMX_HANDLETYPE* pHandle
}
return OMX_ErrorUndefined;
+#else
+ return H263OmxComponentFactory(pHandle, pAppData);
+#endif
}
OMX_ERRORTYPE OmxM4vComponentFactory::H263Destructor(OMX_IN OMX_HANDLETYPE pHandle)
{
+#ifdef HAS_OSCL_LIB_SUPPORT
+
OsclSharedLibrary* lib = OmxM4vComponentFactory::iOmxLib;
// lib must not be NULL at this point. If the omx component has been
@@ -228,7 +253,7 @@ OMX_ERRORTYPE OmxM4vComponentFactory::H263Destructor(OMX_IN OMX_HANDLETYPE pHand
omxIntPtr->QueryOmxComponentInterface(PV_OMX_H263_TYPE, PV_OMX_DESTROY_INTERFACE);
// destroyComp is the function pointer to store the function for
// destroying the omx m4v component.
OMX_ERRORTYPE(*destroyComp)(OMX_IN OMX_HANDLETYPE pHandle);
destroyComp =
OSCL_DYNAMIC_CAST(OMX_ERRORTYPE(*)(OMX_IN OMX_HANDLETYPE), destroyCompTemp);
@@ -248,5 +273,7 @@ OMX_ERRORTYPE OmxM4vComponentFactory::H263Destructor(OMX_IN OMX_HANDLETYPE pHand
}
return returnStatus;
+#else
+ return H263OmxComponentDestructor(pHandle);
+#endif
}
-
@@ -140,12 +156,16 @@ OMX_ERRORTYPE OmxM4vComponentFactory::M4vDestructor(OMX_IN OMX_HANDLETYPE pHandl
}
-// This function is called by OMX_GetHandle and it creates an instance of the m4v component AO
+// This function is called by OMX_GetHandle and it creates an instance of the h263 component AO
// by loading the library where libomx_m4v_component_lib is located
OMX_ERRORTYPE OmxM4vComponentFactory::H263Create(OMX_OUT OMX_HANDLETYPE* pHandle, OMX_IN OMX_PTR pAppData)
@@ -165,7 +185,7 @@ OMX_ERRORTYPE OmxM4vComponentFactory::H263Create(OMX_OUT OMX_HANDLETYPE* pHandle
OmxM4vComponentFactory::iRefCount++;
// Load the associated library. If successful, call the corresponding
- // create function for OMX M4V.
+ // create function for OMX H263.
if (OsclLibSuccess == lib->LoadLib())
{
@@ -228,7 +253,7 @@ OMX_ERRORTYPE OmxM4vComponentFactory::H263Destructor(OMX_IN OMX_HANDLETYPE pHand
omxIntPtr->QueryOmxComponentInterface(PV_OMX_H263_TYPE, PV_OMX_DESTROY_INTERFACE);
// destroyComp is the function pointer to store the function for
- // destroying the omx m4v component.
+ // destroying the omx h263 component.
OMX_ERRORTYPE(*destroyComp)(OMX_IN OMX_HANDLETYPE pHandle);
destroyComp =